#!/Users/ec2-user/ci_py311/portpicker_1678419539246/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehol/bin/python
# EASY-INSTALL-SCRIPT: 'portpicker==1.3.1','portserver.py'
__requires__ = 'portpicker==1.3.1'
__import__('pkg_resources').run_script('portpicker==1.3.1', 'portserver.py')
